@@ -138,7 +138,7 @@ h2o.getModel <- function(model_id) {
   model_category <- json$output$model_category
   if (is.null(model_category))
     model_category <- "Unknown"
-  else if (!(model_category %in% c("Unknown", "Binomial", "Multinomial", "Regression", "Clustering", "AutoEncoder", "DimReduction")))
+  else if (!(model_category %in% c("Unknown", "Binomial", "Multinomial", "Regression", "Clustering", "AutoEncoder", "DimReduction", "WordEmbedding")))
     stop(paste0("model_category, \"", model_category,"\", missing in the output"))
   Class <- paste0("H2O", model_category, "Model")
   model <- json$output[!(names(json$output) %in% c("__meta", "names", "domains", "model_category"))]
@@ -225,7 +225,7 @@ h2o.getModel <- function(model_id) {
 #' my_model <- h2o.gbm(x=1:4, y=5, training_frame=fr)
 #'
 #' h2o.download_pojo(my_model)  # print the model to screen
-#' # h2o.download_pojo(my_model, getwd())  # save the POJO and jar file to the current working 
+#' # h2o.download_pojo(my_model, getwd())  # save the POJO and jar file to the current working
 #' #                                         directory, NOT RUN
 #' # h2o.download_pojo(my_model, getwd(), get_jar = FALSE )  # save only the POJO to the current
 #' #                                                           working directory, NOT RUN
@@ -244,37 +244,38 @@ h2o.download_pojo <- function(model, path=NULL, getjar=NULL, get_jar=TRUE) {
     stop(paste0("'path',",path,", to save pojo cannot be found."))
   }
 
+  #Get model id
   model_id <- model@model_id
-  java <- .h2o.__remoteSend(method = "GET", paste0(.h2o.__MODELS, ".java/", model_id), raw=TRUE)
+
+  #Perform a safe (i.e. error-checked) HTTP GET request to an H2O cluster with POJO URL
+  java <- .h2o.doSafeGET(urlSuffix = paste0(.h2o.__MODELS, ".java/", model_id))
 
   # HACK: munge model._id so that it conforms to Java class name. For example, change K-means to K_means.
   # TODO: clients should extract Java class name from header.
   pojoname = gsub("[+\\-* !@#$%^&()={}\\[\\]|;:'\"<>,.?/]","_",model_id,perl=T)
 
-  file.path <- paste0(path, "/", pojoname, ".java")
+  #Path to save POJO, if `path` is provided
+  file_path <- file.path(path, paste0(pojoname, ".java"))
+
   if( is.null(path) ){
-    cat(java)
+    cat(java) #Pretty print POJO
   } else {
-    write(java, file=file.path)
-      # getjar is now deprecated and the new arg name is get_jar
-      if (!is.null(getjar)) {
-        warning("The `getjar` argument is DEPRECATED; use `get_jar` instead as `getjar` will eventually be removed")
-        get_jar = getjar
-        getjar = NULL
-      }
-    if (get_jar) {
-      .__curlError = FALSE
-      .__curlErrorMessage = ""
-      url = .h2o.calcBaseURL(h2oRestApiVersion = .h2o.__REST_API_VERSION, urlSuffix = "h2o-genmodel.jar")
-      tmp = tryCatch(getBinaryURL(url = url,
-                          useragent = R.version.string),
-                   error = function(x) { .__curlError <<- TRUE; .__curlErrorMessage <<- x$message })
-      if (! .__curlError) {
-        jar.path <- paste0(path, "/h2o-genmodel.jar")
-        writeBin(tmp, jar.path, useBytes = TRUE)
-      }
-    }
-    return(paste0(pojoname,".java"))
+    write(java, file=file_path) #Write POJO to specified path
+  # getjar is now deprecated and the new arg name is get_jar
+  if (!is.null(getjar)) {
+    warning("The `getjar` argument is DEPRECATED; use `get_jar` instead as `getjar` will eventually be removed")
+    get_jar = getjar
+    getjar = NULL
+  }
+  if (get_jar) {
+    urlSuffix = "h2o-genmodel.jar"
+    #Build genmodel.jar file path
+    jar.path <- file.path(path, "h2o-genmodel.jar")
+    #Perform a safe (i.e. error-checked) HTTP GET request to an H2O cluster with genmodel.jar URL
+    #and write to jar.path.
+    writeBin(.h2o.doSafeGET(urlSuffix = urlSuffix, binary = TRUE), jar.path, useBytes = TRUE)
+  }
+  return(paste0(pojoname,".java"))
   }
 }
 
@@ -312,27 +313,24 @@ h2o.download_mojo <- function(model, path=getwd(), get_genmodel_jar=FALSE) {
     stop(paste0("'path',",path,", to save MOJO file cannot be found."))
   }
 
+  #Get model id
   model_id <- model@model_id
-  .__curlError = FALSE
-  .__curlErrorMessage = ""
 
-  url = .h2o.calcBaseURL(h2oRestApiVersion = .h2o.__REST_API_VERSION, urlSuffix = paste0(.h2o.__MODELS,"/",model_id,"/mojo"))
-  tmp = tryCatch(getBinaryURL(url = url,
-                      useragent = R.version.string),
-               error = function(x) { .__curlError <<- TRUE; .__curlErrorMessage <<- x$message })
-  if (! .__curlError) {
-     mojo.path <- paste0(path,"/",model_id,".zip")
-     writeBin(tmp, mojo.path, useBytes = TRUE)
-  }
+  #Build URL for MOJO
+  urlSuffix <- paste0(.h2o.__MODELS,"/",URLencode(model_id),"/mojo")
+
+  #Build MOJO file path and download MOJO file & perform a safe (i.e. error-checked)
+  #HTTP GET request to an H2O cluster with MOJO URL
+  mojo.path <- file.path(path, paste0(model_id,".zip"))
+  writeBin(.h2o.doSafeGET(urlSuffix = urlSuffix, binary = TRUE), mojo.path, useBytes = TRUE)
+
   if (get_genmodel_jar) {
-    url = .h2o.calcBaseURL(h2oRestApiVersion = .h2o.__REST_API_VERSION, urlSuffix = "h2o-genmodel.jar")
-    tmp = tryCatch(getBinaryURL(url = url,
-                        useragent = R.version.string),
-                 error = function(x) { .__curlError <<- TRUE; .__curlErrorMessage <<- x$message })
-    if (! .__curlError) {
-      jar.path <- paste0(path, "/h2o-genmodel.jar")
-      writeBin(tmp, jar.path, useBytes = TRUE)
-    }
+    urlSuffix = "h2o-genmodel.jar"
+    #Build genmodel.jar file path
+    jar.path <- file.path(path,"h2o-genmodel.jar")
+    #Perform a safe (i.e. error-checked) HTTP GET request to an H2O cluster with genmodel.jar URL
+    #and write to jar.path.
+    writeBin(.h2o.doSafeGET(urlSuffix = urlSuffix, binary = TRUE), jar.path, useBytes = TRUE)
   }
   return(paste0(model_id,".zip"))
 }
